PayUUPIBoltPaymentParamsKeys class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accountDetail → const String
amount → const String
firstName → const String
furl → const String
initiationMode → const String
initMode → const String
iosFurl → const String
iosSurl → const String
isCCTxnEnabled → const String
mcc → const String
productInfo → const String
purpose → const String
refCategory → const String
refId → const String
refUrl → const String
splitPaymentDetails → const String
surl → const String
transactionId → const String
tranType → const String
txnId → const String
udf1 → const String
udf2 → const String
udf3 → const String
udf4 → const String
udf5 → const String
userCredentials → const String